oc\_ocdm.graph.entities.bibliographic\_entity module
----------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic_entity
   :members:
   :undoc-members:
   :show-inheritance:
